@@ -408,7 +408,7 @@ __PACKAGE__->add_symbol($_) for(
     [qw/ UsServiceFlow            24     0   nested       0         0           1 /],
     [qw/ UsServiceFlowRef          1    24   ushort       1         65535       1 /],
     [qw/ UsServiceFlowId           2    24   uint         1         4294967295  1 /],
-    [qw/ ServiceClassName          4    24   string       2         16          1 /],
+    [qw/ ServiceClassName          4    24   stringz      2         16          1 /],
     [qw/ QosParamSetType           6    24   uchar        0         255         1 /],
     [qw/ TrafficPriority           7    24   uchar        0         7           1 /],
     [qw/ MaxRateSustained          8    24   uint         0         0           1 /],
@@ -434,7 +434,7 @@ __PACKAGE__->add_symbol($_) for(
     [qw/ DsServiceFlow            25     0   nested       0         0           1 /],
     [qw/ DsServiceFlowRef          1    25   ushort       1         65535       1 /],
     [qw/ DsServiceFlowId           2    25   uint         1         4294967295  1 /],
-    [qw/ ServiceClassName          4    25   string       2         16          1 /],
+    [qw/ ServiceClassName          4    25   stringz      2         16          1 /],
     [qw/ QosParamSetType           6    25   uchar        0         255         1 /],
     [qw/ TrafficPriority           7    25   uchar        0         7           1 /],
     [qw/ MaxRateSustained          8    25   uint         0         4294967295  1 /],
